
#import "Narwhal.h"

%group Narwhal

BOOL shouldHaveUndeleteAction = NO;
id tfComment;
id tfController;

void getUndeleteCommentData(id controller, id comment){
	
	NSMutableURLRequest *request = [[NSMutableURLRequest alloc] init];
	NSOperationQueue *queue = [[NSOperationQueue alloc] init];

	[request setURL:[NSURL URLWithString:[NSString stringWithFormat:@"https://api.pushshift.io/reddit/search/comment/?ids=%@&fields=author,body",[[comment fullName] componentsSeparatedByString:@"_"][1]]]];
	[request setHTTPMethod:@"GET"];		

	[NSURLConnection sendAsynchronousRequest:request queue:queue completionHandler:^(NSURLResponse *response, NSData *data, NSError *error) {
	
		NSString *author = @"[author]";
		NSString *body = @"[body]";

		if (data != nil && error == nil){
			id jsonData = [NSJSONSerialization JSONObjectWithData:data options:0 error:&error];
			if ([[jsonData objectForKey:@"data"] count] != 0){
				author = [[jsonData objectForKey:@"data"][0] objectForKey:@"author"];
				body = [[jsonData objectForKey:@"data"][0] objectForKey:@"body"];
				if ([body isEqualToString:@"[deleted]"] || [body isEqualToString:@"[removed]"]){
					body = @"[pushshift was unable to archive this]";
				}
			} else {
				body = @"[pushshift has not archived this yet]";
			}
		} else if (error != nil || data == nil){
			body = @"[an error occured]";
		}
		
		[controller performSelectorOnMainThread:@selector(completeUndeleteComment:) withObject:@{@"body":body, @"author":author, @"comment":comment} waitUntilDone:NO];
	}];
	
}



%hook UIViewController

-(void) presentViewController:(id) arg1 animated:(BOOL) arg2 completion:(id) arg3{
	
	if ([arg1 isKindOfClass:[UIAlertController class]] && shouldHaveUndeleteAction){
		
		UIAlertAction* undeleteAction;
		
		if (tfComment){
			undeleteAction = [UIAlertAction actionWithTitle:@"tf did that say?" style:nil handler:^(UIAlertAction* action){getUndeleteCommentData(tfController, tfComment);}];
		} else {
			undeleteAction = [UIAlertAction actionWithTitle:@"tf did that say?" style:nil handler:^(UIAlertAction* action){[tfController handleUndeletePostAction];}];
		}
		
		[arg1 addAction:undeleteAction];
		
	}
	
	%orig;
}

%end




%hook NRTLinkViewController

%new
-(void) completeUndeleteComment:(id) data{

	id comment = data[@"comment"];

	if (comment){

		MSHookIvar<NSString*>(comment, "_author") = data[@"author"];
		MSHookIvar<NSString*>(comment, "_body") = data[@"body"];
		
		[[self commentsManager] updateComment:comment fromEdited:comment];
	}
}

%new 
-(void) completeUndeletePost:(id) data{

	id post = data[@"post"];

	MSHookIvar<NSString*>(post, "_author") = data[@"author"];
	
	NSAttributedString* postBodyAttributedString = [%c(NRTMarkdownManager) attributedStringFromMarkdown:data[@"body"] type:0];
	[self setLinkText:postBodyAttributedString];
		
	[[self tableView] reloadData];
}

%new
-(void) handleUndeletePostAction{
	
	id post = [self link];
	
	NSMutableURLRequest *request = [[NSMutableURLRequest alloc] init];
	NSOperationQueue *queue = [[NSOperationQueue alloc] init];

	[request setURL:[NSURL URLWithString:[NSString stringWithFormat:@"https://api.pushshift.io/reddit/search/submission/?ids=%@&fields=author,selftext",[[post fullName] componentsSeparatedByString:@"_"][1]]]];
	[request setHTTPMethod:@"GET"];		

	[NSURLConnection sendAsynchronousRequest:request queue:queue completionHandler:^(NSURLResponse *response, NSData *data, NSError *error) {
		
		NSString *author = @"[author]";
		NSString *body = @"[body]";

		if (data != nil && error == nil){
			id jsonData = [NSJSONSerialization JSONObjectWithData:data options:0 error:&error];
			if ([[jsonData objectForKey:@"data"] count] != 0){
				author = [[jsonData objectForKey:@"data"][0] objectForKey:@"author"];
				body = [[jsonData objectForKey:@"data"][0] objectForKey:@"selftext"];
				if ([body isEqualToString:@"[deleted]"] || [body isEqualToString:@"[removed]"]){
					body = @"[pushshift was unable to archive this]";
				}
			} else {
				body = @"[pushshift has not archived this yet]";
			}
		} else if (error != nil || data == nil){
			body = @"[an error occured]";
		}
		
		[self performSelectorOnMainThread:@selector(completeUndeletePost:) withObject:@{@"body":body, @"author":author, @"post":post} waitUntilDone:NO];
		
	}];
}

-(void) swipeCell:(id) arg1 didEndDragWithState:(NSUInteger) arg2{

	if (arg2 == 2){
		
		if ([arg1 isKindOfClass:[%c(NRTCommentTableViewCell) class]]) {
		
			tfComment = [arg1 comment];
			tfController = self;
			shouldHaveUndeleteAction = YES;
			
		} 
	} 
	
	%orig;
	
	shouldHaveUndeleteAction = NO;
}


-(void) _dotsButtonTouched:(id) arg1{
	
	if ([self linkTextOffscreenCell]){
		
		tfController = self;
		tfComment = nil;
		shouldHaveUndeleteAction = YES;
		
	}
	
	%orig;
	
	shouldHaveUndeleteAction = NO;
}

%end


%hook NRTMediaTableViewDataSource

%new
-(void) completeUndeleteComment:(id) data{

	id comment = data[@"comment"];

	if (comment){

		MSHookIvar<NSString*>(comment, "_author") = data[@"author"];
		MSHookIvar<NSString*>(comment, "_body") = data[@"body"];
		
		[[self commentsManager] updateComment:comment fromEdited:comment];
	}
}

-(void) swipeCell:(id) arg1 didEndDragWithState:(NSUInteger) arg2{

	if (arg2 == 2){
		
		if ([arg1 isKindOfClass:[%c(NRTCommentTableViewCell) class]]) {
			
			tfComment = [arg1 comment];
			tfController = self;
			shouldHaveUndeleteAction = YES;
		
		} 
	} 
	
	%orig;
	
	shouldHaveUndeleteAction = NO;
}

%end

%end

%ctor {
	NSString* processName = [[NSProcessInfo processInfo] processName];

	if ([processName isEqualToString:@"narwhal"]){			
		%init(Narwhal);
	}
}

